/******************************************************************/
/*                                                                */
/*   Include file for K5/VSSP and K5/VSSP32 samplers              */
/*            libipvlbi_board_dummy.h                             */
/*                                                                */
/*     use this include file instead of libipvlbi_board.h in the  */
/*     case of compiling a program on a PC which doesn't install  */
/*     a sampler.                                                 */
/*                                                                */
/*      Version:    2005-08-11                                    */
/*                  2016-05-12                                    */
/*                                                                */
/*      Copyright (c) 2003-2016 T.Kondo/NICT All Right Reserved   */
/*                                                                */
/******************************************************************/
/*
   2007-04-17
        consider in case of C++ 
   2007-02-23 
         board_ref_check, board_ref_check2, board_time_disp were added
   2007-02-22  
        flag_vssp32 was added as a member of vssp_param type valuable
   2007-02-14  delete functions as follows which are no more use
                    sampleget_big, sampleget_old, sampleget0, 
                    sampleget2, sampleget3
   2005-08-11 
       added BUFSIZE. So now libipvlbi_board_dummy.h is different from
       libipvlbi_board.h.

   2005-06-12
       libipvlbi_board_dummy.h and libipvlbi_board.h become identical.
       So, no more use of libipvlbi_board_dummy.h

   2005-06-12
       divided into libipvlbi_board_dummy.h and libipvlbi_board_dummy.c
       
   2007-08-23
       "int bitshift" was added as a member of vssp_param type variable
       dummy function "get_fpga_version" was added.  

   2014-02-07
       DEV_FILE, SAMPLING_RETRY are added

   2016-05-12
       add "get_vssp_drv_name"
       add gloval variable 'char g_dev_file[30]'
   
   
*/
#ifndef _LIBIPVLBI_BOARD_DUMMY_
#define _LIBIPVLBI_BOARD_DUMMY_

#include "chead.h"
#include "libipvlbi.h"

#ifdef linux
  #include <stdint.h>  // necessary for handling uint32_t etc.
  #include <sys/ioctl.h>
#endif

#ifndef BUFSIZE    // added on 2005-08-11
#define BUFSIZE 1024
#endif

/* device driver file set  (added on 2014-02-07) */
/* set VSSP model number and name */
/* set VSSP model number and name */
#if defined(_VSSP32) || defined(_VSSP64) 
  #ifdef _VSSP32
     #define VSSP_MODEL 1                  // VSSP32
     #define VSSP_MODEL_NAME "VSSP32"      // VSSP32
  #else
     #define VSSP_MODEL 2                  // VSSP64
     #define VSSP_MODEL_NAME "VSSP64"      // VSSP64
  #endif
#else
     #define VSSP_MODEL 0                  // VSSP
     #define VSSP_MODEL_NAME "VSSP"        // VSSP
#endif

/* global variable for device file  (newly defined on 2016-05-12) */
char g_dev_file[30];


#ifndef _LIBIPVLBI_

typedef struct listoutdir    
{            
    int  dirnum;   // maximum number of directories
    int  ndir;     // next directory index#  2005-01-30
    char dir[10][120];
} listoutdir_t;

typedef struct logval    // structural variablle for log
{            
    char logdir[60];     // logfile directory
    char hostname[20];   // host name
    char logfile[80];    //log file name
    int logfiletype;     // logfile naming type
                         //  0: exocode_stationid.hostname.log
                         //  1: YYYY+hostname+".log"
                         //       where  YYYY is 4 digit year
                         //  -1: no log
} logval_t;

typedef struct vsspaux  // VSSP32 AUX field type  for K5/VSSP32  (moved to libipvlbi.h)
{
    int size;    // AUX filed size
    int fmt;     // AUX field format
    char bdat[256];   // AUX field data
    char sid[2];        // 1 char Station ID
    char sid2[3];       // 2 char Station ID
    char station8[20];       // station name (1st 8 char is valid)
    char hostname8[20];       // Host PC name (1st 8 char is valid)
} vsspaux_t;

typedef struct vssp_param   // sampling parameter type variable  (moved to libipvlbi.h)
{
    int sfreq;
    int adbit;
    int numch;
    int filter;  // filter frequency(MHz)  0: no use of K5/VSSP32
    int freqkhz;  // frequency in kHz  (used for only return param)
    int flag_vssp32;  // 0: K5/VSSP   1: K5/VSSP32
    vsspaux_t vsspaux;  // AUX filed data for K5/VSSP32 2005-12-28
                        // vsspaux_t is defined in libipvlbi.h
} vssp_param_t;

typedef struct spget   // sampleget type variable (moved to libipvlbi.h)
{
    int span;
    //int sfreq;
    //int adbit;
    //int numch;
    //int filter;  // filter frequency(MHz)  0: no use of K5/VSSP32
    vssp_param_t sp; 
    int f_size_mode;  // 0: no limitation on file size  
                      // 1: divided into 2GB size 
    char outfile[120];
    char fname[120]; 
    char outdir[120];
    listoutdir_t outdirtab;  //2005-01-30
    logval_t lg;
    //vsspaux_t vsspaux;  // AUX filed data for K5/VSSP32 2005-12-28
                        // vsspaux_t is defined in libipvlbi.h
} spget_t;
#endif



#ifdef __cplusplus
extern "C"{
#endif 

// prototype 
int ini_sampler(int *fd_in, vssp_param_t *sp, int *bitsec);
int start_sampler(int *fd_in);
int stop_sampler(int *fd_in);
int ini_and_start_sampler(int *fd_in, vssp_param_t *sp, int *bitsec);
int sampleget(spget_t *spg);
int sampleget4(spget_t *spg, int mode);
int ip_board_time(unsigned int *day, unsigned int *sec, int *hh, int *mm, int *ss);
int toffset_get(int *yearPC, float *tofset); //added on 2003/08/21 
int LogWrite2(char* logdir, char* hostname, int time_mode, 
              float secofset, int mode, char* cbuf);  //added on 2003/06/16
void LogWrite3(char* logdir, char* hostname, char* logfile, int logfiletype,
              int time_mode,  float secofset, int mode, char* cbuf);
void LogWrite4(logval_t *lg, int time_mode,  float secofset, int mode, 
               char* cbuf);


int check_vssp(int fd_in, unsigned int *stat, int verbose);
int set_vssp_sparam(int fd_in, vssp_param_t *sp, int verbose);
int get_vssp_sparam(int fd_in, vssp_param_t *sp, int verbose);
int vssp_wait_nsec(int fd_in, int nsec);

/****** added 2007-02-23 ****/
unsigned int board_ref_check(int fd_in);
int board_ref_check2(int fd_in);
int board_time_disp(int secmax);
int get_fpga_version(void);
   
/****** added 2016-05-12 ****/
void get_vssp_drv_name(int model, char *dev_file);

#ifdef __cplusplus
}
#endif

#endif
